@@ -1,9 +1,5 @@
 import 'nextra-theme-docs/style.css'
 
 export default function Nextra({ Component, pageProps }) {
-  return (
-    <>
-      <Component {...pageProps} />
-    </>
-  )
+  return <Component {...pageProps} />
 }
