@@ -1,11 +1,11 @@
 'use strict'
 
-var Client = require('../')
-var assert = require('assert')
+const Client = require('../')
+const assert = require('assert')
 
 describe('connection errors', function () {
   it('raise error events', function (done) {
-    var client = new Client()
+    const client = new Client()
     client.connectSync()
     client.query('SELECT pg_terminate_backend(pg_backend_pid())', assert.fail)
     client.on('error', function (err) {
