@@ -1,16 +1,16 @@
-var Client = require('../')
-var assert = require('assert')
+const Client = require('../')
+const assert = require('assert')
 
-var checkDomain = function (domain, when) {
+const checkDomain = function (domain, when) {
   assert(process.domain, 'Domain was lost after ' + when)
   assert.strictEqual(process.domain, domain, 'Domain switched after ' + when)
 }
 
 describe('domains', function () {
   it('remains bound after a query', function (done) {
-    var domain = require('domain').create() // eslint-disable-line
+    const domain = require('domain').create()
     domain.run(function () {
-      var client = new Client()
+      const client = new Client()
       client.connect(function () {
         checkDomain(domain, 'connection')
         client.query('SELECT NOW()', function () {
