@@ -3,7 +3,7 @@
 const BufferList = function () {
   this.buffers = []
 }
-var p = BufferList.prototype
+const p = BufferList.prototype
 
 p.add = function (buffer, front) {
   this.buffers[front ? 'unshift' : 'push'](buffer)
@@ -28,16 +28,16 @@ p.addInt32 = function (val, first) {
 }
 
 p.addCString = function (val, front) {
-  var len = Buffer.byteLength(val)
-  var buffer = Buffer.alloc(len + 1)
+  const len = Buffer.byteLength(val)
+  const buffer = Buffer.alloc(len + 1)
   buffer.write(val)
   buffer[len] = 0
   return this.add(buffer, front)
 }
 
 p.addString = function (val, front) {
-  var len = Buffer.byteLength(val)
-  var buffer = Buffer.alloc(len)
+  const len = Buffer.byteLength(val)
+  const buffer = Buffer.alloc(len)
   buffer.write(val)
   return this.add(buffer, front)
 }
@@ -47,7 +47,7 @@ p.addChar = function (char, first) {
 }
 
 p.join = function (appendLength, char) {
-  var length = this.getByteLength()
+  let length = this.getByteLength()
   if (appendLength) {
     this.addInt32(length + 4, true)
     return this.join(false, char)
@@ -56,8 +56,8 @@ p.join = function (appendLength, char) {
     this.addChar(char, true)
     length++
   }
-  var result = Buffer.alloc(length)
-  var index = 0
+  const result = Buffer.alloc(length)
+  let index = 0
   this.buffers.forEach(function (buffer) {
     buffer.copy(result, index, 0)
     index += buffer.length
