@@ -1,8 +1,8 @@
 'use strict'
-var ConnectionParameters = require('../lib/connection-parameters')
-var config = new ConnectionParameters(process.argv[2])
+const ConnectionParameters = require('../lib/connection-parameters')
+const config = new ConnectionParameters(process.argv[2])
 
-for (var i = 0; i < process.argv.length; i++) {
+for (let i = 0; i < process.argv.length; i++) {
   switch (process.argv[i].toLowerCase()) {
     case 'native':
       config.native = true
