@@ -1,5 +1,5 @@
 'use strict'
-var helper = require('./test-helper')
+const helper = require('./test-helper')
 const suite = new helper.Suite()
 const pg = helper.pg
 const assert = require('assert')
@@ -9,7 +9,7 @@ client.connect(
   assert.success(function () {
     client.query('begin')
 
-    var getZed = {
+    const getZed = {
       text: 'SELECT * FROM person WHERE name = $1',
       values: ['Zed'],
     }
