@@ -1,17 +1,17 @@
 'use strict'
-var helper = require('./test-helper')
-var co = require('co')
+const helper = require('./test-helper')
+const co = require('co')
 const assert = require('assert')
 
 const pool = new helper.pg.Pool()
 new helper.Suite().test(
   'using coroutines works with promises',
   co.wrap(function* () {
-    var client = yield pool.connect()
-    var res = yield client.query('SELECT $1::text as name', ['foo'])
+    const client = yield pool.connect()
+    const res = yield client.query('SELECT $1::text as name', ['foo'])
     assert.equal(res.rows[0].name, 'foo')
 
-    var threw = false
+    let threw = false
     try {
       yield client.query('SELECT LKDSJDSLKFJ')
     } catch (e) {
