@@ -1,8 +1,8 @@
 'use strict'
 
-var helper = require('./test-helper')
-var Query = helper.pg.Query
-var suite = new helper.Suite()
+const helper = require('./test-helper')
+const Query = helper.pg.Query
+const suite = new helper.Suite()
 
 const assert = require('assert')
 const Pool = helper.pg.Pool
@@ -22,9 +22,9 @@ suite.test('no domain', function (cb) {
 suite.test('with domain', function (cb) {
   assert(!process.domain)
   const pool = new Pool()
-  var domain = require('domain').create()
+  const domain = require('domain').create()
   domain.run(function () {
-    var startingDomain = process.domain
+    const startingDomain = process.domain
     assert(startingDomain)
     pool.connect(
       assert.success(function (client, done) {
@@ -46,7 +46,7 @@ suite.test('with domain', function (cb) {
 })
 
 suite.test('error on domain', function (cb) {
-  var domain = require('domain').create()
+  const domain = require('domain').create()
   const pool = new Pool()
   domain.on('error', function () {
     pool.end(cb)
