@@ -1,15 +1,15 @@
 'use strict'
-var helper = require('./../test-helper')
-var assert = require('assert')
+const helper = require('./../test-helper')
+const assert = require('assert')
 
-var callbackError = new Error('TEST: Throw in callback')
+const callbackError = new Error('TEST: Throw in callback')
 
 const suite = new helper.Suite()
 
 suite.test('it should cleanup client even if an error is thrown in a callback', (done) => {
   // temporarily replace the test framework's uncaughtException handlers
   // with a custom one that ignores the callbackError
-  let original_handlers = process.listeners('uncaughtException')
+  const original_handlers = process.listeners('uncaughtException')
   process.removeAllListeners('uncaughtException')
   process.on('uncaughtException', (err) => {
     if (err != callbackError) {
@@ -18,7 +18,7 @@ suite.test('it should cleanup client even if an error is thrown in a callback',
   })
 
   // throw an error in a callback and verify that a subsequent query works without error
-  var client = helper.client()
+  const client = helper.client()
   client.query('SELECT NOW()', (err) => {
     assert(!err)
     setTimeout(reuseClient, 50)
@@ -30,7 +30,7 @@ suite.test('it should cleanup client even if an error is thrown in a callback',
       assert(!err)
 
       // restore the test framework's uncaughtException handlers
-      for (let handler of original_handlers) {
+      for (const handler of original_handlers) {
         process.on('uncaughtException', handler)
       }
 
