@@ -1,6 +1,6 @@
 'use strict'
-var helper = require('../test-helper')
-var copyFrom = require('pg-copy-streams').from
+const helper = require('../test-helper')
+const copyFrom = require('pg-copy-streams').from
 
 if (helper.args.native) return
 
@@ -8,12 +8,12 @@ const pool = new helper.pg.Pool()
 pool.connect(function (err, client, done) {
   if (err) throw err
 
-  var c = 'CREATE TEMP TABLE employee (id integer, fname varchar(400), lname varchar(400))'
+  const c = 'CREATE TEMP TABLE employee (id integer, fname varchar(400), lname varchar(400))'
 
   client.query(c, function (err) {
     if (err) throw err
 
-    var stream = client.query(copyFrom('COPY employee FROM STDIN'))
+    const stream = client.query(copyFrom('COPY employee FROM STDIN'))
     stream.on('end', function () {
       done()
       setTimeout(() => {
@@ -21,8 +21,8 @@ pool.connect(function (err, client, done) {
       }, 50)
     })
 
-    for (var i = 1; i <= 5; i++) {
-      var line = ['1\ttest', i, '\tuser', i, '\n']
+    for (let i = 1; i <= 5; i++) {
+      const line = ['1\ttest', i, '\tuser', i, '\n']
       stream.write(line.join(''))
     }
     stream.end()
