@@ -1,7 +1,7 @@
 'use strict'
 // client should not hang on an empty query
-var helper = require('../test-helper')
-var client = helper.client()
+const helper = require('../test-helper')
+const client = helper.client()
 client.query({ name: 'foo1', text: null })
 client.query({ name: 'foo2', text: '   ' })
 client.query({ name: 'foo3', text: '' }, function (err, res) {
