@@ -1,5 +1,7 @@
 'use strict'
-var helper = require('./../test-helper')
+const helper = require('./../test-helper')
+let { Client } = helper
+const assert = require('assert')
 
 if (helper.args.native) {
   Client = require('./../../lib/native')
@@ -9,7 +11,7 @@ if (helper.args.native) {
 
 // creates a client from cli parameters
 helper.client = function (cb) {
-  var client = new Client()
+  const client = new Client()
   client.connect(cb)
   return client
 }
@@ -19,7 +21,7 @@ helper.versionGTE = function (client, testVersion, callback) {
     'SHOW server_version_num',
     assert.calls(function (err, result) {
       if (err) return callback(err)
-      var version = parseInt(result.rows[0].server_version_num, 10)
+      const version = parseInt(result.rows[0].server_version_num, 10)
       return callback(null, version >= testVersion)
     })
   )
