@@ -1,12 +1,12 @@
 'use strict'
-var domain = require('domain')
-var helper = require('./../test-helper')
-var Client = require('./../../lib/native')
+const domain = require('domain')
+const helper = require('./../test-helper')
+const Client = require('./../../lib/native')
 const suite = new helper.Suite()
 const assert = require('assert')
 
 suite.test('fires callback with results', function (done) {
-  var client = new Client(helper.config)
+  const client = new Client(helper.config)
   client.connect()
   client.query(
     'SELECT 1 as num',
@@ -28,10 +28,10 @@ suite.test('fires callback with results', function (done) {
 })
 
 suite.test('preserves domain', function (done) {
-  var dom = domain.create()
+  const dom = domain.create()
 
   dom.run(function () {
-    var client = new Client(helper.config)
+    const client = new Client(helper.config)
     assert.ok(dom === require('domain').active, 'domain is active')
     client.connect()
     client.query('select 1', function () {
