@@ -1,15 +1,15 @@
 'use strict'
-var helper = require('../test-helper')
-var Client = require('../../lib/native')
-var Query = Client.Query
+const helper = require('../test-helper')
+const Client = require('../../lib/native')
+const Query = Client.Query
 const assert = require('assert')
 const suite = new helper.Suite()
 
 suite.test('many rows', function () {
-  var client = new Client(helper.config)
+  const client = new Client(helper.config)
   client.connect()
-  var q = client.query(new Query('SELECT * FROM person'))
-  var rows = []
+  const q = client.query(new Query('SELECT * FROM person'))
+  const rows = []
   q.on('row', function (row) {
     rows.push(row)
   })
@@ -20,12 +20,12 @@ suite.test('many rows', function () {
 })
 
 suite.test('many queries', function () {
-  var client = new Client(helper.config)
+  const client = new Client(helper.config)
   client.connect()
-  var count = 0
-  var expected = 100
-  for (var i = 0; i < expected; i++) {
-    var q = client.query(new Query('SELECT * FROM person'))
+  let count = 0
+  const expected = 100
+  for (let i = 0; i < expected; i++) {
+    const q = client.query(new Query('SELECT * FROM person'))
     assert.emits(q, 'end', function () {
       count++
     })
@@ -37,13 +37,13 @@ suite.test('many queries', function () {
 })
 
 suite.test('many clients', function () {
-  var clients = []
-  for (var i = 0; i < 10; i++) {
+  const clients = []
+  for (let i = 0; i < 10; i++) {
     clients.push(new Client(helper.config))
   }
   clients.forEach(function (client) {
     client.connect()
-    for (var i = 0; i < 20; i++) {
+    for (let i = 0; i < 20; i++) {
       client.query('SELECT * FROM person')
     }
     assert.emits(client, 'drain', function () {
