@@ -1,43 +1,43 @@
 'use strict'
-var helper = require('./test-helper')
-var utils = require('../../../lib/utils')
+const helper = require('./test-helper')
+const utils = require('../../../lib/utils')
 const assert = require('assert')
 const { Client, Suite } = helper
 const suite = new Suite()
 const test = suite.test.bind(suite)
 
-var testLit = function (testName, input, expected) {
+const testLit = function (testName, input, expected) {
   test(testName, function () {
-    var client = new Client(helper.config)
-    var actual = client.escapeLiteral(input)
+    const client = new Client(helper.config)
+    const actual = client.escapeLiteral(input)
     assert.equal(expected, actual)
   })
 
   test('Client.prototype.' + testName, function () {
-    var actual = Client.prototype.escapeLiteral(input)
+    const actual = Client.prototype.escapeLiteral(input)
     assert.equal(expected, actual)
   })
 
   test('utils.' + testName, function () {
-    var actual = utils.escapeLiteral(input)
+    const actual = utils.escapeLiteral(input)
     assert.equal(expected, actual)
   })
 }
 
-var testIdent = function (testName, input, expected) {
+const testIdent = function (testName, input, expected) {
   test(testName, function () {
-    var client = new Client(helper.config)
-    var actual = client.escapeIdentifier(input)
+    const client = new Client(helper.config)
+    const actual = client.escapeIdentifier(input)
     assert.equal(expected, actual)
   })
 
   test('Client.prototype.' + testName, function () {
-    var actual = Client.prototype.escapeIdentifier(input)
+    const actual = Client.prototype.escapeIdentifier(input)
     assert.equal(expected, actual)
   })
 
   test('utils.' + testName, function () {
-    var actual = utils.escapeIdentifier(input)
+    const actual = utils.escapeIdentifier(input)
     assert.equal(expected, actual)
   })
 }
