@@ -1,12 +1,12 @@
 'use strict'
-var helper = require('./test-helper')
+const helper = require('./test-helper')
 const assert = require('assert')
 const suite = new helper.Suite()
 const test = suite.test.bind(suite)
 
-var testForTag = function (tagText, callback) {
+const testForTag = function (tagText, callback) {
   test('includes command tag data for tag ' + tagText, function () {
-    var client = helper.client()
+    const client = helper.client()
     client.connection.emit('readyForQuery')
 
     client.query(
@@ -26,7 +26,7 @@ var testForTag = function (tagText, callback) {
   })
 }
 
-var check = function (oid, rowCount, command) {
+const check = function (oid, rowCount, command) {
   return function (result) {
     if (oid != null) {
       assert.equal(result.oid, oid)
