@@ -1,12 +1,12 @@
 'use strict'
 const helper = require('./test-helper')
-var Connection = require('../../../lib/connection')
-var Client = require('../../../lib/client')
+const Connection = require('../../../lib/connection')
+const Client = require('../../../lib/client')
 const assert = require('assert')
 const suite = new helper.Suite()
 
 suite.test('emits end when not in query', function () {
-  var stream = new (require('events').EventEmitter)()
+  const stream = new (require('events').EventEmitter)()
   stream.setNoDelay = () => {}
   stream.connect = function () {
     // NOOP
@@ -15,7 +15,7 @@ suite.test('emits end when not in query', function () {
     // NOOP
   }
 
-  var client = new Client({ connection: new Connection({ stream: stream }) })
+  const client = new Client({ connection: new Connection({ stream: stream }) })
   client.connect(
     assert.calls(function () {
       client.query(
