@@ -1,17 +1,17 @@
 'use strict'
-var helper = require('../test-helper')
-var Connection = require('../../../lib/connection')
+const helper = require('../test-helper')
+const Connection = require('../../../lib/connection')
 const { Client } = helper
 
-var makeClient = function () {
-  var connection = new Connection({ stream: 'no' })
+const makeClient = function () {
+  const connection = new Connection({ stream: 'no' })
   connection.startup = function () {}
   connection.connect = function () {}
   connection.query = function (text) {
     this.queries.push(text)
   }
   connection.queries = []
-  var client = new Client({ connection: connection })
+  const client = new Client({ connection: connection })
   client.connect()
   client.connection.emit('connect')
   return client
